@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023 Advanced Micro Devices, Inc.
+/* Copyright (c) 2019-2024 Advanced Micro Devices, Inc.
 
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -352,6 +352,10 @@ to_string (amd_dbgapi_status_t status)
       CASE (STATUS_ERROR_SYMBOL_NOT_FOUND);
       CASE (STATUS_ERROR_REGISTER_NOT_AVAILABLE);
       CASE (STATUS_ERROR_INVALID_WORKGROUP_ID);
+      CASE (STATUS_ERROR_INCOMPATIBLE_PROCESS_STATE);
+      CASE (STATUS_ERROR_PROCESS_FROZEN);
+      CASE (STATUS_ERROR_PROCESS_ALREADY_FROZEN);
+      CASE (STATUS_ERROR_PROCESS_NOT_FROZEN);
     }
   return to_string (make_hex (status));
 }
@@ -563,6 +567,46 @@ to_string (detail::query_ref<amd_dbgapi_instruction_kind_t> ref)
                to_cstring (kind));
 }
 
+template <>
+std::string
+to_string (amd_dbgapi_client_process_info_t client_process_info)
+{
+  switch (client_process_info)
+    {
+      CASE (CLIENT_PROCESS_INFO_OS_PID);
+      CASE (CLIENT_PROCESS_INFO_CORE_STATE);
+    }
+  return to_string (make_hex (client_process_info));
+}
+
+template <>
+std::string
+to_string (amd_dbgapi_core_state_data_t core_state)
+{
+  return string_printf (
+    "{endian %s, data %s}",
+    core_state.endianness == AMD_DBGAPI_ENDIAN_BIG ? "BIG" : "LITTLE",
+    to_cstring (make_hex (make_ref (core_state.data, core_state.size))));
+}
+
+template <>
+std::string
+to_string (detail::query_ref<amd_dbgapi_client_process_info_t> ref)
+{
+  auto [query, value] = ref;
+  switch (query)
+    {
+    case AMD_DBGAPI_CLIENT_PROCESS_INFO_OS_PID:
+      return to_string (
+        make_ref (static_cast<const amd_dbgapi_os_process_id_t *> (value)));
+    case AMD_DBGAPI_CLIENT_PROCESS_INFO_CORE_STATE:
+      return to_string (
+        make_ref (static_cast<const amd_dbgapi_core_state_data_t *> (value)));
+    }
+  fatal_error ("unhandled amd_dbgapi_client_process_info_t query (%s)",
+               to_cstring (query));
+}
+
 template <>
 std::string
 to_string (amd_dbgapi_process_info_t process_info)
@@ -574,6 +618,8 @@ to_string (amd_dbgapi_process_info_t process_info)
       CASE (PROCESS_INFO_WATCHPOINT_SHARE);
       CASE (PROCESS_INFO_PRECISE_MEMORY_SUPPORTED);
       CASE (PROCESS_INFO_OS_ID);
+      CASE (PROCESS_INFO_CORE_STATE);
+      CASE (PROCESS_INFO_PRECISE_ALU_EXCEPTIONS_SUPPORTED);
     }
   return to_string (make_hex (process_info));
 }
@@ -599,6 +645,12 @@ to_string (detail::query_ref<amd_dbgapi_process_info_t> ref)
     case AMD_DBGAPI_PROCESS_INFO_OS_ID:
       return to_string (
         make_ref (static_cast<const amd_dbgapi_os_process_id_t *> (value)));
+    case AMD_DBGAPI_PROCESS_INFO_CORE_STATE:
+      return to_string (
+        make_ref (static_cast<const amd_dbgapi_core_state_data_t *> (value)));
+    case AMD_DBGAPI_PROCESS_INFO_PRECISE_ALU_EXCEPTIONS_SUPPORTED:
+      return to_string (make_ref (
+        static_cast<const amd_dbgapi_alu_exceptions_precision_t *> (value)));
     }
   fatal_error ("unhandled amd_dbgapi_process_info_t query (%s)",
                to_cstring (query));
@@ -907,7 +959,7 @@ one_queue_error_reason_to_string (amd_dbgapi_exceptions_t queue_error_reason)
       CASE (EXCEPTION_WAVE_MATH_ERROR);
       CASE (EXCEPTION_WAVE_ILLEGAL_INSTRUCTION);
       CASE (EXCEPTION_WAVE_MEMORY_VIOLATION);
-      CASE (EXCEPTION_WAVE_APERTURE_VIOLATION);
+      CASE (EXCEPTION_WAVE_ADDRESS_ERROR);
       CASE (EXCEPTION_PACKET_DISPATCH_DIM_INVALID);
       CASE (EXCEPTION_PACKET_DISPATCH_GROUP_SEGMENT_SIZE_INVALID);
       CASE (EXCEPTION_PACKET_DISPATCH_CODE_INVALID);
@@ -1167,7 +1219,7 @@ one_stop_reason_to_string (amd_dbgapi_wave_stop_reasons_t stop_reason)
       CASE (WAVE_STOP_REASON_ASSERT_TRAP);
       CASE (WAVE_STOP_REASON_TRAP);
       CASE (WAVE_STOP_REASON_MEMORY_VIOLATION);
-      CASE (WAVE_STOP_REASON_APERTURE_VIOLATION);
+      CASE (WAVE_STOP_REASON_ADDRESS_ERROR);
       CASE (WAVE_STOP_REASON_ILLEGAL_INSTRUCTION);
       CASE (WAVE_STOP_REASON_ECC_ERROR);
       CASE (WAVE_STOP_REASON_FATAL_HALT);
@@ -1451,6 +1503,18 @@ to_string (amd_dbgapi_memory_precision_t memory_precision)
   return to_string (make_hex (memory_precision));
 }
 
+template <>
+std::string
+to_string (amd_dbgapi_alu_exceptions_precision_t alu_exceptions_precision)
+{
+  switch (alu_exceptions_precision)
+    {
+      CASE (ALU_EXCEPTIONS_PRECISION_NONE);
+      CASE (ALU_EXCEPTIONS_PRECISION_PRECISE);
+    }
+  return to_string (make_hex (alu_exceptions_precision));
+}
+
 template <>
 std::string
 to_string (amd_dbgapi_event_kind_t event_kind)
@@ -1587,6 +1651,10 @@ one_launch_trap_mask_to_string (os_wave_launch_trap_mask_t value)
       return "int_divide_by_zero";
     case os_wave_launch_trap_mask_t::address_watch:
       return "address_watch";
+    case os_wave_launch_trap_mask_t::wave_start:
+      return "wave_start";
+    case os_wave_launch_trap_mask_t::wave_end:
+      return "wave_end";
     }
   return to_string (
     make_hex (static_cast<std::underlying_type_t<decltype (value)>> (value)));
