@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023 Advanced Micro Devices, Inc.
+/* Copyright (c) 2019-2024 Advanced Micro Devices, Inc.
 
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -158,7 +158,7 @@ struct parameter_t
   }
 };
 
-} /* namespapce detail */
+} /* namespace detail */
 
 template <char const *name, detail::parameter_kind_t kind, typename T>
 constexpr auto
@@ -482,8 +482,10 @@ to_string (detail::parameter_t<detail::query_ref<T>, name, kind> param)
   F (amd_dbgapi_breakpoint_id_t)                                              \
   F (amd_dbgapi_breakpoint_info_t)                                            \
   F (amd_dbgapi_changed_t)                                                    \
+  F (amd_dbgapi_client_process_info_t)                                        \
   F (amd_dbgapi_code_object_id_t)                                             \
   F (amd_dbgapi_code_object_info_t)                                           \
+  F (amd_dbgapi_core_state_data_t)                                            \
   F (amd_dbgapi_direct_call_register_pair_information_t)                      \
   F (amd_dbgapi_dispatch_barrier_t)                                           \
   F (amd_dbgapi_dispatch_fence_scope_t)                                       \
@@ -499,6 +501,7 @@ to_string (detail::parameter_t<detail::query_ref<T>, name, kind> param)
   F (amd_dbgapi_instruction_properties_t)                                     \
   F (amd_dbgapi_log_level_t)                                                  \
   F (amd_dbgapi_memory_precision_t)                                           \
+  F (amd_dbgapi_alu_exceptions_precision_t)                                   \
   F (amd_dbgapi_os_queue_type_t)                                              \
   F (amd_dbgapi_process_id_t)                                                 \
   F (amd_dbgapi_process_info_t)                                               \
@@ -532,6 +535,7 @@ to_string (detail::parameter_t<detail::query_ref<T>, name, kind> param)
   F (detail::query_ref<amd_dbgapi_address_space_info_t>)                      \
   F (detail::query_ref<amd_dbgapi_architecture_info_t>)                       \
   F (detail::query_ref<amd_dbgapi_breakpoint_info_t>)                         \
+  F (detail::query_ref<amd_dbgapi_client_process_info_t>)                     \
   F (detail::query_ref<amd_dbgapi_code_object_info_t>)                        \
   F (detail::query_ref<amd_dbgapi_dispatch_info_t>)                           \
   F (detail::query_ref<amd_dbgapi_displaced_stepping_info_t>)                 \
