@@ -61,6 +61,12 @@ enum elf_amdgpu_machine_t : uint32_t
   EF_AMDGPU_MACH_AMDGCN_GFX1102 = 0x047,
   EF_AMDGPU_MACH_AMDGCN_GFX1200 = 0x048,
   EF_AMDGPU_MACH_AMDGCN_GFX1201 = 0x04e,
+  EF_AMDGPU_MACH_AMDGCN_GFX9_GENERIC = 0x051,
+  EF_AMDGPU_MACH_AMDGCN_GFX10_1_GENERIC = 0x052,
+  EF_AMDGPU_MACH_AMDGCN_GFX10_3_GENERIC = 0x053,
+  EF_AMDGPU_MACH_AMDGCN_GFX11_GENERIC = 0x054,
+  EF_AMDGPU_MACH_AMDGCN_GFX12_GENERIC = 0x059,
+  EF_AMDGPU_MACH_AMDGCN_GFX9_4_GENERIC = 0x05f
 };
 
 using os_agent_id_t = uint32_t;
