@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023 Advanced Micro Devices, Inc.
+/* Copyright (c) 2019-2024 Advanced Micro Devices, Inc.
 
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -109,8 +109,13 @@ private:
   os_wave_launch_mode_t m_wave_launch_mode{ os_wave_launch_mode_t::normal };
   os_wave_launch_trap_mask_t m_wave_trap_mask{};
 
+  bool m_frozen{ false };
+
   bool m_supports_precise_memory{ false };
-  bool m_precise_memory{ false };
+
+  bool m_supports_precise_alu_exceptions{ false };
+
+  os_process_flags_t m_process_flags{};
 
   bool m_forward_progress_needed{ true };
 
@@ -163,6 +168,8 @@ public:
     return m_rocr_debug_version;
   }
 
+  bool from_core () const { return !m_os_process_id.has_value (); }
+
   /* Reset all the handle_object_sets IDs.  There should not be any attached
      processes left in the s_process_map. */
   static void reset_all_ids ();
@@ -224,8 +231,12 @@ public:
   void set_wave_launch_trap_override (os_wave_launch_trap_mask_t value,
                                       os_wave_launch_trap_mask_t mask);
 
+  bool is_frozen () const { return m_frozen; }
+
   void set_precise_memory (bool enabled);
 
+  void set_precise_alu_exceptions (bool enabled);
+
   /* Suspend/resume a list of queues.  Queues may become invalid as a result of
      suspension/resumption, but not destroyed.  Queues made invalid will
      destroy associated dispatches and waves.  Since waves/dispatches can be
@@ -255,6 +266,9 @@ public:
   void attach ();
   void detach ();
 
+  void freeze ();
+  void unfreeze ();
+
   void enqueue_event (event_t &event);
   event_t *next_pending_event ();
 
@@ -282,7 +296,9 @@ public:
   void get_info (amd_dbgapi_process_info_t query, size_t value_size,
                  void *value) const;
 
-  amd_dbgapi_status_t get_os_pid (amd_dbgapi_os_process_id_t *pid) const;
+  amd_dbgapi_status_t
+  client_process_get_info (amd_dbgapi_client_process_info_t query,
+                           size_t value_size, void *value) const;
   amd_dbgapi_status_t
   insert_breakpoint (amd_dbgapi_global_address_t address,
                      amd_dbgapi_breakpoint_id_t breakpoint_id);
