@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023 Advanced Micro Devices, Inc.
+/* Copyright (c) 2019-2024 Advanced Micro Devices, Inc.
 
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -399,6 +399,7 @@ amd_dbgapi_register_get_info (amd_dbgapi_register_id_t register_id,
          AMD_DBGAPI_STATUS_ERROR_INVALID_REGISTER_ID,
          AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT,
          AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT_COMPATIBILITY,
+         AMD_DBGAPI_STATUS_ERROR_NOT_AVAILABLE,
          AMD_DBGAPI_STATUS_ERROR_CLIENT_CALLBACK);
   TRACE_END (make_query_ref (query, param_out (value)));
 }
@@ -596,6 +597,9 @@ amd_dbgapi_write_register (amd_dbgapi_wave_id_t wave_id,
     if (wave == nullptr)
       THROW (AMD_DBGAPI_STATUS_ERROR_INVALID_WAVE_ID);
 
+    if (wave->process ().is_frozen ())
+      THROW (AMD_DBGAPI_STATUS_ERROR_PROCESS_FROZEN);
+
     auto regnum = architecture_t::register_id_to_regnum (register_id);
 
     const architecture_t *architecture
@@ -630,7 +634,8 @@ amd_dbgapi_write_register (amd_dbgapi_wave_id_t wave_id,
          AMD_DBGAPI_STATUS_ERROR_DISPLACED_STEPPING_ACTIVE,
          AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT,
          AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT_COMPATIBILITY,
-         AMD_DBGAPI_STATUS_ERROR_REGISTER_NOT_AVAILABLE);
+         AMD_DBGAPI_STATUS_ERROR_REGISTER_NOT_AVAILABLE,
+         AMD_DBGAPI_STATUS_ERROR_PROCESS_FROZEN);
   TRACE_END ();
 }
 
