@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023 Advanced Micro Devices, Inc.
+/* Copyright (c) 2019-2024 Advanced Micro Devices, Inc.
 
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -494,7 +494,7 @@ struct doubly_linked_entry_t : private not_copyable_t
     m_next = rhs.m_next;
     m_prev = rhs.m_prev;
     m_next->m_prev = this;
-    m_prev->n_next = this;
+    m_prev->m_next = this;
     rhs.m_next = rhs.m_prev = nullptr;
   }
   doubly_linked_entry_t &operator= (doubly_linked_entry_t &&rhs) noexcept
@@ -502,7 +502,7 @@ struct doubly_linked_entry_t : private not_copyable_t
     m_next = rhs.m_next;
     m_prev = rhs.m_prev;
     m_next->m_prev = this;
-    m_prev->n_next = this;
+    m_prev->m_next = this;
     rhs.m_next = rhs.m_prev = nullptr;
   }
 
